==> uilite-1.0.68.tgz: package/main.ts <==
#!/usr/bin/env node
import {executeCmd} from "./utilt"
import * as fs from "fs"
import * as path from "path";
let argumentList:any=process.argv;
let currentDir=process.cwd();
let rootPath=path.join(__dirname,"..");
let argObj:any=convertArgJson();
let buildpath="build";
let staticPath="public";
let projectName="";
if(argObj && argObj.project){
  projectName=argObj.project;
  let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json","utf-8"))
  let projectData=projectJson[argObj.project];
  buildpath=projectData?.build_path || "build";
  staticPath=projectData?.static_path || "public";
}
if(argumentList.length>2){
    if(argumentList[2]=="serve" ){
        try{
            let cmd=`npx webpack serve --config ${rootPath}/webpack.config.js`
            if(projectName){
              cmd=cmd+" --env project="+projectName;
            }
            executeCmd(cmd)
            .then((result)=>{
                console.log(result);
            })
            .catch((err)=>{
                console.log("err",err)
            })
       }
       catch(err){
        console.log(err);
       }
    }
    else if(argumentList[2]=="build"){
      let cmd=`npx webpack --config ${rootPath}/webpack-build.config.js`
      if(projectName){
        cmd=cmd+" --env project="+projectName
      }
      if(!fs.existsSync(currentDir+"/"+buildpath)){
         fs.mkdirSync(currentDir+"/"+buildpath)
      }
      fs.cpSync(currentDir+"/"+staticPath,currentDir+"/"+buildpath,{recursive:true});
      executeCmd(cmd)
      .then((result)=>{
          console.log(result);
      })
      .catch((err)=>{
          console.log("err",err)
      })
    }
  else if(argumentList[2]=="create"){
    fs.cpSync(rootPath+"/example",currentDir,{recursive:true});
  }

}

function convertArgJson(){
  let argList=process.argv;
  let obj={};
  argList.forEach((d,i)=>{
    if(d.search("--")>=0){
       let key=d.replace("--","");
       obj[key]=argList[i+1];
    }
  })
  return obj;
}

==> uilite-1.0.72.tgz: package/main.ts <==
#!/usr/bin/env node
import {executeCmd} from "./utilt"
import * as fs from "fs"
import * as path from "path";
let argumentList:any=process.argv;
let currentDir=process.cwd();
let rootPath=path.join(__dirname,"..");
let argObj:any=convertArgJson();
let buildpath="build";
let staticPath="public";
let projectName="";
if(argObj && argObj.project){
  projectName=argObj.project;
  let projectJson=JSON.parse(fs.readFileSync(process.cwd()+"/project.json","utf-8"))
  let projectData=projectJson[argObj.project];
  buildpath=projectData?.build_path || "build";
  staticPath=projectData?.static_path || "public";
}
if(argumentList.length>2){
    if(argumentList[2]=="serve" ){
        try{
            let cmd=`npx webpack serve --config ${rootPath}/webpack.config.js`
            if(projectName){
              cmd=cmd+" --env project="+projectName;
            }
            executeCmd(cmd)
            .then((result)=>{
                console.log(result);
            })
            .catch((err)=>{
                console.log("err",err)
            })
       }
       catch(err){
        console.log(err);
       }
    }
    else if(argumentList[2]=="build"){
      let cmd=`npx webpack --config ${rootPath}/webpack-build.config.js`
      if(projectName){
        cmd=cmd+" --env project="+projectName
      }
      if(!fs.existsSync(currentDir+"/"+buildpath)){
         fs.mkdirSync(currentDir+"/"+buildpath)
      }
      if(!fs.existsSync(currentDir+"/"+buildpath+"/asset")){
        fs.mkdirSync(currentDir+"/"+buildpath+"/asset")
     }
      fs.cpSync(currentDir+"/"+staticPath+"/asset",currentDir+"/"+buildpath+"/asset",{recursive:true});
      executeCmd(cmd)
      .then((result)=>{
          console.log(result);
      })
      .catch((err)=>{
          console.log("err",err)
      })
    }
  else if(argumentList[2]=="create"){
    fs.cpSync(rootPath+"/example",currentDir,{recursive:true});
  }

}

function convertArgJson(){
  let argList=process.argv;
  let obj={};
  argList.forEach((d,i)=>{
    if(d.search("--")>=0){
       let key=d.replace("--","");
       obj[key]=argList[i+1];
    }
  })
  return obj;
}
